pub struct LuaString(/* private fields */);Expand description
Handle to an internal Lua string.
Unlike Rust strings, Lua strings may not be valid UTF-8.
Implementations
Sourceimpl LuaString
impl LuaString
Sourcepub fn to_str(&self) -> Result<BorrowedStr>
pub fn to_str(&self) -> Result<BorrowedStr>
Get a BorrowedStr if the Lua string is valid UTF-8.
The returned BorrowedStr holds a strong reference to the Lua state to guarantee the
validity of the underlying data.
Examples
let globals = lua.globals();
let version: LuaString = globals.get("_VERSION")?;
assert!(version.to_str()?.contains("Lua"));
let non_utf8: LuaString = lua.load(r#" "test\255" "#).eval()?;
assert!(non_utf8.to_str().is_err());Sourcepub fn to_string_lossy(&self) -> String
pub fn to_string_lossy(&self) -> String
Converts this Lua string to a String.
Any non-Unicode sequences are replaced with U+FFFD REPLACEMENT CHARACTER.
This method returns String instead of Cow<'_, str> because lifetime cannot be
bound to a weak Lua object.
Examples
let lua = Lua::new();
let s = lua.create_string(b"test\xff")?;
assert_eq!(s.to_string_lossy(), "test\u{fffd}");Sourcepub fn as_bytes(&self) -> BorrowedBytes
pub fn as_bytes(&self) -> BorrowedBytes
Get the bytes that make up this string.
The returned BorrowedStr holds a strong reference to the Lua state to guarantee the
validity of the underlying data. The data will not contain the terminating null byte, but
will contain any null bytes embedded into the Lua string.
Examples
let non_utf8: LuaString = lua.load(r#" "test\255" "#).eval()?;
assert!(non_utf8.to_str().is_err()); // oh no :(
assert_eq!(non_utf8.as_bytes(), &b"test\xff"[..]);Sourcepub fn as_bytes_with_nul(&self) -> BorrowedBytes
pub fn as_bytes_with_nul(&self) -> BorrowedBytes
Get the bytes that make up this string, including the trailing null byte.
Sourcepub fn to_pointer(&self) -> *const c_void
pub fn to_pointer(&self) -> *const c_void
Converts this Lua string to a generic C pointer.
There is no way to convert the pointer back to its original value.
Typically this function is used only for hashing and debug information.