pub trait MaybeSync: Sync { }Expand description
A trait that adds Sync requirement if send feature is enabled.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait MaybeSync: Sync { }A trait that adds Sync requirement if send feature is enabled.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".